@@ -23,7 +23,8 @@ SOFTWARE.
 """
 from cereja.utils import get_version_pep440_compliant
 from . import settings
-from .devices import Capture, Mouse
+from .devices import Capture, Mouse, VideoMagnify
+from .media import Image
 
-VERSION = "1.0.5.final.0"
+VERSION = "1.0.7.final.0"
 __version__ = get_version_pep440_compliant(VERSION)
